@@ -3,8 +3,9 @@ import logging
 from twisted.internet.defer import Deferred
 
 from peek_core_device.server.DeviceApiABC import DeviceApiABC
-from peek_core_user._private.server.controller.LoginLogoutController import \
-    LoginLogoutController
+from peek_core_user._private.server.controller.LoginLogoutController import (
+    LoginLogoutController,
+)
 from peek_core_user.server.UserLoginApiABC import UserLoginApiABC
 from peek_core_user.tuples.login.UserLoginAction import UserLoginAction
 from peek_core_user.tuples.login.UserLogoutAction import UserLogoutAction
@@ -16,7 +17,7 @@ class UserLoginApi(UserLoginApiABC):
     #: A reference to the core device plugins API
     _deviceApi: DeviceApiABC
 
-    def __init__(self, loginLogoutController:LoginLogoutController):
+    def __init__(self, loginLogoutController: LoginLogoutController):
         self._loginLogoutController = loginLogoutController
 
     def shutdown(self):
@@ -25,6 +26,5 @@ class UserLoginApi(UserLoginApiABC):
     def logout(self, logoutTuple: UserLogoutAction) -> Deferred:
         return self._loginLogoutController.logout(logoutTuple)
 
-
     def login(self, loginTuple: UserLoginAction) -> Deferred:
-        return self._loginLogoutController.login(loginTuple)
\ No newline at end of file
+        return self._loginLogoutController.login(loginTuple)
